@@ -7,7 +7,7 @@ use Rose::DB::Object::MakeMethods::Date;
 use Rose::DB::Object::Metadata::Column::Date;
 our @ISA = qw(Rose::DB::Object::Metadata::Column::Date);
 
-our $VERSION = '0.70';
+our $VERSION = '0.771';
 
 __PACKAGE__->add_common_method_maker_argument_names
 (
@@ -30,9 +30,9 @@ sub type { 'datetime' }
 sub should_inline_value
 {
   #my($self, $db, $value) = @_;
-  my $driver = $_[1]->driver;
-  return ($_[1]->validate_datetime_keyword($_[2]) && 
-          (($driver eq 'informix' || $driver eq 'sqlite') || $_[2] =~ /^\w+\(.*\)$/)) ? 1 : 0;
+  no warnings 'uninitialized';
+  return (($_[1]->validate_datetime_keyword($_[2]) && $_[1]->should_inline_datetime_keywords) || 
+          $_[2] =~ /^\w+\(.*\)$/) ? 1 : 0;
 }
 
 sub parse_value
