@@ -8,7 +8,7 @@ use Rose::DB::Object::MakeMethods::Generic;
 use Rose::DB::Object::Metadata::Column;
 our @ISA = qw(Rose::DB::Object::Metadata::Column);
 
-our $VERSION = '0.765';
+our $VERSION = '0.771';
 
 __PACKAGE__->add_common_method_maker_argument_names
 (
@@ -33,6 +33,14 @@ sub type { 'set' }
 sub parse_value  { shift; shift->parse_set(@_)  }
 sub format_value { shift; shift->format_set(@_) }
 
+sub should_inline_value
+{
+  #my($self, $db, $value) = @_;
+  no warnings 'uninitialized';
+  return (($_[1]->validate_set_keyword($_[2]) && $_[1]->should_inline_set_keywords) || 
+          $_[2] =~ /^\w+\(.*\)$/) ? 1 : 0;
+}
+
 sub method_uses_formatted_key
 {
   my($self, $type) = @_;
