@@ -9,7 +9,7 @@ use Rose::DB::Object::Metadata::Util qw(:all);
 use Rose::DB::Object::Metadata::MethodMaker;
 our @ISA = qw(Rose::DB::Object::Metadata::MethodMaker);
 
-our $VERSION = '0.61';
+our $VERSION = '0.771';
 
 __PACKAGE__->add_common_method_maker_argument_names
 (
@@ -29,6 +29,8 @@ Rose::Object::MakeMethods::Generic->make_methods
 
 sub type { Carp::confess "Override in subclass" }
 
+sub is_singular { Carp::confess "Override in subclass" }
+
 sub relationship { $_[0] }
 
 sub is_ready_to_make_methods { 1 }
@@ -235,7 +237,7 @@ sub object_has_related_objects
     return @{$related_objects} ? $related_objects : 0;
   }
 
-  return $ref ? [ $related_objects ] : 0;
+  return $ref ? [ $related_objects ] : undef;
 }
 
 sub hash_keys_used { shift->hash_key }
@@ -371,6 +373,12 @@ Return a method name for the relationship method type TYPE.  Subclasses must ove
 
 Get or set the name of the L<Rose::DB::Object>-derived class that fronts the foreign table referenced by this relationship.
 
+=item B<is_singular>
+
+Returns true of the relationship may refer to more than one related object, false otherwise.  For example, this method returns true for L<Rose::DB::Object::Metadata::Relationship::OneToMany/is_singular> objects, but false for L<Rose::DB::Object::Metadata::Relationship::ManyToOne/is_singular> objects.
+
+Relationship subclasses must override this method and return an appropriate value.
+
 =item B<make_methods PARAMS>
 
 Create object method used to manipulate objects in related tables.  Any applicable column triggers are also added.  PARAMS are name/value pairs.  Valid PARAMS are:
