@@ -5,10 +5,12 @@ use strict;
 use Rose::DB::Object::Metadata::Relationship::ManyToOne;
 our @ISA = qw(Rose::DB::Object::Metadata::Relationship::ManyToOne);
 
-our $VERSION = '0.761';
+our $VERSION = '0.771';
 
 sub type { 'one to one' }
 
+sub is_singular { 1 }
+
 sub requires_preexisting_parent_object
 {
   my($self) = shift;
@@ -109,6 +111,10 @@ For the method types "delete_now" and "delete_on_save", the relationship's  L<na
 
 Otherwise, undef is returned.
 
+=item B<is_singular>
+
+Returns true.
+
 =item B<foreign_key [FK]>
 
 Get or set the L<Rose::DB::Object::Metadata::ForeignKey> object to which this object delegates all responsibility.
